from mpi_exec import run_mpi
from seq_exec import run_sequential
from multi_exec import run_multiprocessor
from concurrency_exec import run_concurrent
from utils import *

import os

def main():

    # PARSE ARGS:
    mode = "seq"
    num_files = 5
    numbers_per_file = 1000
    problem_size = num_files * numbers_per_file

    if problem_size % 2 != 0:
        print("problem_size must be divisible by 2")

    # GENERATE INPUTS (if not created already)
    print("STARTING PYTHON DUMMY BENCHMARK")
    print("MODE: {}, NUM_FILES: {} numbers_per_file: {} ".
          format(mode, num_files, numbers_per_file))

    generate_inputs(num_files, numbers_per_file)

    if mode == "seq":
        run_sequential(num_files)
    elif mode == "mp":
        run_multiprocessor()
    elif mode == "concurrent":
        run_concurrent()
    elif mode == "mpi":
        run_mpi()
    else:
        print(f"MODE {mode} NOT RECOGNIZED")


    print("ENDING")

@dec_measure(">generate inputs")
@dec_print("Generating inputs...")
def generate_inputs(n_files, nums_per_file):
    for f in range(n_files):
        aux = Path(f"{f}_input.bin")
        if check_file_exists(aux):
            os.remove(aux)
        gen_binary_file(aux, nums_per_file)

if __name__ == "__main__":
    main()

